@@ -10,7 +10,7 @@ use WebService::SSLLabs::Host();
 use WebService::SSLLabs::Endpoint();
 use WebService::SSLLabs::StatusCodes();
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub new {
     my ($class) = @_;
@@ -62,9 +62,7 @@ sub analyze {
     if ( $response->is_success() ) {
         my $host = WebService::SSLLabs::Host->new(
             JSON::decode_json( $response->decoded_content() ) );
-        if ( $host->status() eq 'READY' ) {
-            return $host;
-        }
+        return $host;
     }
     else {
         Carp::croak( "Failed to retrieve $url:" . $response->status_line() );
@@ -132,7 +130,7 @@ WebService::SSLLabs - Analyze the configuration of any SSL web server on the pub
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =head1 SYNOPSIS
 
@@ -142,11 +140,13 @@ Check the security of your TLS services
 
     my $labs = WebService::SSLLabs->new();
     my $host;
-    while(not $host = $labs->analyze(host => 'ssllabs.com')) {
+    while(not $host = $labs->analyze(host => 'ssllabs.com')->done()) {
         sleep 10;
     }
-    foreach my $endpoint ($host->endpoints()) {
-        say $host->host() . ' at ' . $endpoint->ip_address() . ' gets a ' . $endpoint->grade();
+    if ($host->status() eq 'READY') {
+       foreach my $endpoint ($host->endpoints()) {
+           say $host->host() . ' at ' . $endpoint->ip_address() . ' gets a ' . $endpoint->grade();
+       }
     }
 
 =head1 DESCRIPTION
