@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use WebService::SSLLabs::Endpoint();
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 sub new {
     my ( $class, $json ) = @_;
@@ -12,12 +12,23 @@ sub new {
     my @endpoints = @{ $self->{endpoints} };
     $self->{endpoints} = [];
     foreach my $endpoint (@endpoints) {
-        push @{ $self->{endpoints} }, WebService::SSLLabs::Endpoint->new($endpoint);
+        push @{ $self->{endpoints} },
+          WebService::SSLLabs::Endpoint->new($endpoint);
     }
     bless $self, $class;
     return $self;
 }
 
+sub done {
+    my ($self) = @_;
+    if ( $self->status() =~ /^READY|ERROR$/smxi ) {
+        return $self;
+    }
+    else {
+        return;
+    }
+}
+
 sub status {
     my ($self) = @_;
     return $self->{status};
@@ -82,7 +93,7 @@ WebService::SSLLabs::Host - Host object
 
 =head1 VERSION
 
-Version 0.11
+Version 0.12
 
 =head1 SUBROUTINES/METHODS
 
@@ -90,6 +101,10 @@ Version 0.11
 
 a new C<WebService::SSLLabs::Host> object, accepts a hash ref as it's parameter.
 
+=head2 done
+
+will return the current C<WebService::SSLLabs::Host> object if L<status|WebService::SSLLabs::Host/"status"> is equal to READY or ERROR.  Otherwise it will return undef.
+
 =head2 host 
 
 assessment host, which can be a hostname or an IP address
